@@ -89,6 +89,9 @@ var (
 	// it is locked. "conflict" followed by newline is used to preserve go-tfe version
 	// compatibility with the error constructed at runtime before it was defined here.
 	ErrWorkspaceLockedCannotDelete = errors.New("conflict\nWorkspace is currently locked. Workspace must be unlocked before it can be safely deleted")
+
+	// ErrHYOKCannotBeDisabled is returned when attempting to disable HYOK on a workspace that already has it enabled.
+	ErrHYOKCannotBeDisabled = errors.New("bad request\n\nhyok may not be disabled once it has been turned on for a workspace")
 )
 
 // Invalid values for resources/struct fields
@@ -123,6 +126,8 @@ var (
 
 	ErrInvalidPagination = errors.New("invalid value for page size or number")
 
+	ErrInvalidReservedTagKeyID = errors.New("invalid value for reserved tag key ID")
+
 	ErrInvalidRunTaskCategory = errors.New(`category must be "task"`)
 
 	ErrInvalidRunTaskID = errors.New("invalid value for run task ID")
@@ -238,6 +243,14 @@ var (
 	ErrInvalidTaskResultsCallbackStatus = fmt.Errorf("invalid value for task result status. Must be either `%s`, `%s`, or `%s`", TaskFailed, TaskPassed, TaskRunning)
 
 	ErrInvalidDescriptionConflict = errors.New("invalid attributes\n\nValidation failed: Description has already been taken")
+
+	ErrInvalidOIDC = errors.New("invalid value for OIDC configuration ID")
+
+	ErrInvalidHYOK = errors.New("invalid value for HYOK configuration ID")
+
+	ErrInvalidHYOKCustomerKeyVersion = errors.New("invalid value for HYOK Customer key version ID")
+
+	ErrInvalidHYOKEncryptedDataKey = errors.New("invalid value for HYOK encrypted data key ID")
 )
 
 var (
@@ -245,12 +258,12 @@ var (
 
 	ErrRequiredAgentPoolID = errors.New("'agent' execution mode requires an agent pool ID to be specified")
 
-	ErrRequiredAgentMode                = errors.New("specifying an agent pool ID requires 'agent' execution mode")
-	ErrRequiredBranchWhenTestsEnabled   = errors.New("VCS branch is required when enabling tests")
-	ErrBranchMustBeEmptyWhenTagsEnabled = errors.New("VCS branch must be empty to enable tags")
-	ErrRequiredCategory                 = errors.New("category is required")
-
-	ErrRequiredDestinationType = errors.New("destination type is required")
+	ErrRequiredAgentMode                      = errors.New("specifying an agent pool ID requires 'agent' execution mode")
+	ErrRequiredBranchWhenTestsEnabled         = errors.New("VCS branch is required when enabling tests")
+	ErrBranchMustBeEmptyWhenTagsEnabled       = errors.New("VCS branch must be empty to enable tags")
+	ErrRequiredCategory                       = errors.New("category is required")
+	ErrAgentPoolNotRequiredForRemoteExecution = errors.New("'remote' execution mode does not support agent pool IDs")
+	ErrRequiredDestinationType                = errors.New("destination type is required")
 
 	ErrRequiredDataType = errors.New("data type is required")
 
@@ -390,6 +403,8 @@ var (
 
 	ErrInvalidTestRunID = errors.New("invalid value for test run id")
 
+	ErrInvalidQueryRunID = errors.New("invalid value for query run id")
+
 	ErrTerraformVersionValidForPlanOnly = errors.New("setting terraform-version is only valid when plan-only is set to true")
 
 	ErrStateMustBeOmitted = errors.New("when uploading state, the State and JSONState strings must be omitted from options")
@@ -397,4 +412,38 @@ var (
 	ErrRequiredRawState = errors.New("RawState is required")
 
 	ErrStateVersionUploadNotSupported = errors.New("upload not supported by this version of Terraform Enterprise")
+
+	ErrSanitizedStateUploadURLMissing = errors.New("sanitized state upload URL is missing")
+
+	ErrRequiredRoleARN = errors.New("role-arn is required for AWS OIDC configuration")
+
+	ErrRequiredServiceAccountEmail = errors.New("service-account-email is required for GCP OIDC configuration")
+
+	ErrRequiredProjectNumber = errors.New("project-number is required for GCP OIDC configuration")
+
+	ErrRequiredWorkloadProviderName = errors.New("workload-provider-name is required for GCP OIDC configuration")
+
+	ErrRequiredClientID = errors.New("client-id is required for Azure OIDC configuration")
+
+	ErrRequiredSubscriptionID = errors.New("subscription-id is required for Azure OIDC configuration")
+
+	ErrRequiredTenantID = errors.New("tenant-id is required for Azure OIDC configuration")
+
+	ErrRequiredVaultAddress = errors.New("address is required for Vault OIDC configuration")
+
+	ErrRequiredRoleName = errors.New("role is required for Vault OIDC configuration")
+
+	ErrRequiredKEKID = errors.New("kek-id is required for HYOK configuration")
+
+	ErrRequiredOIDCConfiguration = errors.New("oidc-configuration is required for HYOK configuration")
+
+	ErrRequiredAgentPool = errors.New("agent-pool is required for HYOK configuration")
+
+	ErrRequiredKMSOptions = errors.New("kms-options is required for HYOK configuration")
+
+	ErrRequiredKMSOptionsKeyRegion = errors.New("kms-options.key-region is required for HYOK configuration with AWS OIDC")
+
+	ErrRequiredKMSOptionsKeyLocation = errors.New("kms-options.key-location is required for HYOK configuration with GCP OIDC")
+
+	ErrRequiredKMSOptionsKeyRingID = errors.New("kms-options.key-ring-id is required for HYOK configuration with GCP OIDC")
 )
