@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2016, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package database
@@ -258,6 +258,8 @@ func (b *databaseBackend) pathRoleDelete(ctx context.Context, req *logical.Reque
 		return nil, err
 	}
 	b.dbEvent(ctx, "role-delete", req.Path, name, true)
+	recordDatabaseObservation(ctx, b, req, "", ObservationTypeDatabaseRoleDelete,
+		AdditionalDatabaseMetadata{key: "role_name", value: name})
 	return nil, nil
 }
 
@@ -299,11 +301,14 @@ func (b *databaseBackend) pathStaticRoleDelete(ctx context.Context, req *logical
 	}
 
 	b.dbEvent(ctx, "static-role-delete", req.Path, name, true)
+	recordDatabaseObservation(ctx, b, req, "", ObservationTypeDatabaseStaticRoleDelete,
+		AdditionalDatabaseMetadata{key: "role_name", value: name})
 	return nil, merr.ErrorOrNil()
 }
 
 func (b *databaseBackend) pathStaticRoleRead(ctx context.Context, req *logical.Request, d *framework.FieldData) (*logical.Response, error) {
-	role, err := b.StaticRole(ctx, req.Storage, d.Get("name").(string))
+	roleName := d.Get("name").(string)
+	role, err := b.StaticRole(ctx, req.Storage, roleName)
 	if err != nil {
 		return nil, err
 	}
@@ -345,13 +350,17 @@ func (b *databaseBackend) pathStaticRoleRead(ctx context.Context, req *logical.R
 		data["rotation_statements"] = []string{}
 	}
 
+	recordDatabaseObservation(ctx, b, req, role.DBName, ObservationTypeDatabaseStaticRoleRead,
+		AdditionalDatabaseMetadata{key: "role_name", value: roleName})
+
 	return &logical.Response{
 		Data: data,
 	}, nil
 }
 
 func (b *databaseBackend) pathRoleRead(ctx context.Context, req *logical.Request, d *framework.FieldData) (*logical.Response, error) {
-	role, err := b.Role(ctx, req.Storage, d.Get("name").(string))
+	roleName := d.Get("name").(string)
+	role, err := b.Role(ctx, req.Storage, roleName)
 	if err != nil {
 		return nil, err
 	}
@@ -385,6 +394,9 @@ func (b *databaseBackend) pathRoleRead(ctx context.Context, req *logical.Request
 		data["renew_statements"] = []string{}
 	}
 
+	recordDatabaseObservation(ctx, b, req, role.DBName, ObservationTypeDatabaseRoleRead,
+		AdditionalDatabaseMetadata{key: "role_name", value: roleName})
+
 	return &logical.Response{
 		Data: data,
 	}, nil
@@ -428,6 +440,7 @@ func (b *databaseBackend) pathRoleCreateUpdate(ctx context.Context, req *logical
 	createOperation := (req.Operation == logical.CreateOperation)
 
 	// DB Attributes
+	var credentialType string
 	{
 		if dbNameRaw, ok := data.GetOk("db_name"); ok {
 			role.DBName = dbNameRaw.(string)
@@ -439,7 +452,7 @@ func (b *databaseBackend) pathRoleCreateUpdate(ctx context.Context, req *logical
 		}
 
 		if credentialTypeRaw, ok := data.GetOk("credential_type"); ok {
-			credentialType := credentialTypeRaw.(string)
+			credentialType = credentialTypeRaw.(string)
 			if err := role.setCredentialType(credentialType); err != nil {
 				return logical.ErrorResponse(err.Error()), nil
 			}
@@ -516,6 +529,21 @@ func (b *databaseBackend) pathRoleCreateUpdate(ctx context.Context, req *logical
 	}
 
 	b.dbEvent(ctx, fmt.Sprintf("role-%s", req.Operation), req.Path, name, true)
+
+	if createOperation {
+		recordDatabaseObservation(ctx, b, req, role.DBName, ObservationTypeDatabaseRoleCreate,
+			AdditionalDatabaseMetadata{key: "role_name", value: name},
+			AdditionalDatabaseMetadata{key: "credential_type", value: credentialType},
+			AdditionalDatabaseMetadata{key: "default_ttl", value: role.DefaultTTL.String()},
+			AdditionalDatabaseMetadata{key: "max_ttl", value: role.MaxTTL.String()})
+	} else {
+		recordDatabaseObservation(ctx, b, req, role.DBName, ObservationTypeDatabaseRoleUpdate,
+			AdditionalDatabaseMetadata{key: "role_name", value: name},
+			AdditionalDatabaseMetadata{key: "credential_type", value: credentialType},
+			AdditionalDatabaseMetadata{key: "default_ttl", value: role.DefaultTTL.String()},
+			AdditionalDatabaseMetadata{key: "max_ttl", value: role.MaxTTL.String()})
+	}
+
 	return nil, nil
 }
 
@@ -535,6 +563,13 @@ func (b *databaseBackend) pathStaticRoleRecover(ctx context.Context, req *logica
 	}
 
 	name := data.Get("name").(string)
+	if req.RecoverSourcePath != "" {
+		fd, err := b.RecoverSourcePathFieldData(req)
+		if err != nil {
+			return nil, fmt.Errorf("failed to parse the recover source path: %w", err)
+		}
+		name = fd.Get("name").(string)
+	}
 
 	role, err := b.StaticRole(ctx, snapStorage, name)
 	if err != nil {
@@ -669,8 +704,9 @@ func (b *databaseBackend) pathStaticRoleCreateUpdate(ctx context.Context, req *l
 		role.Statements.Rotation = data.Get("rotation_statements").([]string)
 	}
 
+	var credentialType string
 	if credentialTypeRaw, ok := data.GetOk("credential_type"); ok {
-		credentialType := credentialTypeRaw.(string)
+		credentialType = credentialTypeRaw.(string)
 		if err := role.setCredentialType(credentialType); err != nil {
 			return logical.ErrorResponse(err.Error()), nil
 		}
@@ -832,6 +868,31 @@ func (b *databaseBackend) pathStaticRoleCreateUpdate(ctx context.Context, req *l
 	}
 	b.dbEvent(ctx, fmt.Sprintf("static-role-%s", req.Operation), req.Path, name, true)
 
+	var nextVaultRotation time.Time
+	var rotationPeriod time.Duration
+	if role.StaticAccount != nil {
+		nextVaultRotation = role.StaticAccount.NextVaultRotation
+		rotationPeriod = role.StaticAccount.RotationPeriod
+	}
+
+	if req.Operation == logical.CreateOperation {
+		recordDatabaseObservation(ctx, b, req, role.DBName, ObservationTypeDatabaseStaticRoleCreate,
+			AdditionalDatabaseMetadata{key: "role_name", value: name},
+			AdditionalDatabaseMetadata{key: "credential_type", value: role.CredentialType.String()},
+			AdditionalDatabaseMetadata{key: "rotation_period", value: rotationPeriod.String()},
+			AdditionalDatabaseMetadata{key: "rotation_schedule", value: rotationScheduleRaw},
+			AdditionalDatabaseMetadata{key: "next_vault_rotation", value: nextVaultRotation.String()},
+		)
+	} else {
+		recordDatabaseObservation(ctx, b, req, role.DBName, ObservationTypeDatabaseStaticRoleUpdate,
+			AdditionalDatabaseMetadata{key: "role_name", value: name},
+			AdditionalDatabaseMetadata{key: "credential_type", value: role.CredentialType.String()},
+			AdditionalDatabaseMetadata{key: "rotation_period", value: rotationPeriod.String()},
+			AdditionalDatabaseMetadata{key: "rotation_schedule", value: rotationScheduleRaw},
+			AdditionalDatabaseMetadata{key: "next_vault_rotation", value: nextVaultRotation.String()},
+		)
+	}
+
 	if len(response.Warnings) == 0 {
 		return nil, nil
 	}
