@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2016, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package pki
@@ -16,6 +16,7 @@ import (
 	"time"
 
 	"github.com/hashicorp/vault/builtin/logical/pki/issuing"
+	"github.com/hashicorp/vault/builtin/logical/pki/observe"
 	"github.com/hashicorp/vault/sdk/framework"
 	"github.com/hashicorp/vault/sdk/helper/certutil"
 	"github.com/hashicorp/vault/sdk/helper/strutil"
@@ -159,7 +160,7 @@ func addFieldsForACMEOrder(fields map[string]*framework.FieldSchema) {
 	}
 }
 
-func (b *backend) acmeFetchCertOrderHandler(ac *acmeContext, _ *logical.Request, fields *framework.FieldData, uc *jwsCtx, data map[string]interface{}, _ *acmeAccount) (*logical.Response, error) {
+func (b *backend) acmeFetchCertOrderHandler(ac *acmeContext, req *logical.Request, fields *framework.FieldData, uc *jwsCtx, data map[string]interface{}, _ *acmeAccount) (*logical.Response, error) {
 	orderId := fields.Get("order_id").(string)
 
 	order, err := b.GetAcmeState().LoadOrder(ac, uc, orderId)
@@ -213,6 +214,25 @@ func (b *backend) acmeFetchCertOrderHandler(ac *acmeContext, _ *logical.Request,
 		return nil, fmt.Errorf("failed encoding certificate ca chain: %w", err)
 	}
 
+	var role string
+	var issuerName string
+	var issuerId string
+	if ac.Role != nil {
+		role = ac.Role.Name
+	}
+	if ac.Issuer != nil {
+		issuerId = ac.Issuer.ID.String()
+		issuerName = ac.Issuer.Name
+	}
+	b.pkiObserver.RecordPKIObservation(ac, req, observe.ObservationTypePKIAcmeFetchOrderCert,
+		observe.NewAdditionalPKIMetadata("role", role),
+		observe.NewAdditionalPKIMetadata("issuer_name", issuerName),
+		observe.NewAdditionalPKIMetadata("issuer_id", issuerId),
+		observe.NewAdditionalPKIMetadata("order_id", order.OrderId),
+		observe.NewAdditionalPKIMetadata("serial_number", order.CertificateSerialNumber),
+		observe.NewAdditionalPKIMetadata("account_id", order.AccountId),
+	)
+
 	return &logical.Response{
 		Data: map[string]interface{}{
 			logical.HTTPContentType: "application/pem-certificate-chain",
@@ -276,6 +296,7 @@ func (b *backend) acmeFinalizeOrderHandler(ac *acmeContext, r *logical.Request,
 		if err != nil {
 			return nil, err
 		}
+		b.pkiCertificateCounter.AddIssuedCertificate(true)
 	}
 	hyphenSerialNumber := normalizeSerialFromBigInt(signedCertBundle.Certificate.SerialNumber)
 
@@ -300,6 +321,29 @@ func (b *backend) acmeFinalizeOrderHandler(ac *acmeContext, r *logical.Request,
 		err = nil
 	}
 
+	var role string
+	var issuerName string
+	var stored bool
+	if ac.Role != nil {
+		role = ac.Role.Name
+		stored = !ac.Role.NoStore
+	}
+	if ac.Issuer != nil {
+		issuerName = ac.Issuer.Name
+	}
+
+	b.pkiObserver.RecordPKIObservation(ac, r, observe.ObservationTypePKIAcmeFinalizeOrder,
+		observe.NewAdditionalPKIMetadata("role", role),
+		observe.NewAdditionalPKIMetadata("issuer_name", issuerName),
+		observe.NewAdditionalPKIMetadata("issuer_id", issuerId.String()),
+		observe.NewAdditionalPKIMetadata("order_id", order.OrderId),
+		observe.NewAdditionalPKIMetadata("stored", stored),
+		observe.NewAdditionalPKIMetadata("serial_number", order.CertificateSerialNumber),
+		observe.NewAdditionalPKIMetadata("certificate_expiry", order.CertificateExpiry.String()),
+		observe.NewAdditionalPKIMetadata("status", ACMEOrderValid),
+		observe.NewAdditionalPKIMetadata("account_id", order.AccountId),
+	)
+
 	return formatOrderResponse(ac, order), nil
 }
 
@@ -636,7 +680,7 @@ func parseCsrFromFinalize(data map[string]interface{}) (*x509.CertificateRequest
 	return csr, nil
 }
 
-func (b *backend) acmeGetOrderHandler(ac *acmeContext, _ *logical.Request, fields *framework.FieldData, uc *jwsCtx, _ map[string]interface{}, _ *acmeAccount) (*logical.Response, error) {
+func (b *backend) acmeGetOrderHandler(ac *acmeContext, req *logical.Request, fields *framework.FieldData, uc *jwsCtx, _ map[string]interface{}, _ *acmeAccount) (*logical.Response, error) {
 	orderId := fields.Get("order_id").(string)
 
 	order, err := b.GetAcmeState().LoadOrder(ac, uc, orderId)
@@ -672,10 +716,28 @@ func (b *backend) acmeGetOrderHandler(ac *acmeContext, _ *logical.Request, field
 		order.AuthorizationIds = filteredAuthorizationIds
 	}
 
+	var role string
+	var issuerName string
+	var issuerId string
+	if ac.Role != nil {
+		role = ac.Role.Name
+	}
+	if ac.Issuer != nil {
+		issuerName = ac.Issuer.Name
+		issuerId = ac.Issuer.ID.String()
+	}
+
+	b.pkiObserver.RecordPKIObservation(ac, req, observe.ObservationTypePKIAcmeGetOrder,
+		observe.NewAdditionalPKIMetadata("role", role),
+		observe.NewAdditionalPKIMetadata("issuer_name", issuerName),
+		observe.NewAdditionalPKIMetadata("issuer_id", issuerId),
+		observe.NewAdditionalPKIMetadata("order_id", orderId),
+	)
+
 	return formatOrderResponse(ac, order), nil
 }
 
-func (b *backend) acmeListOrdersHandler(ac *acmeContext, _ *logical.Request, _ *framework.FieldData, uc *jwsCtx, _ map[string]interface{}, acct *acmeAccount) (*logical.Response, error) {
+func (b *backend) acmeListOrdersHandler(ac *acmeContext, req *logical.Request, _ *framework.FieldData, uc *jwsCtx, _ map[string]interface{}, acct *acmeAccount) (*logical.Response, error) {
 	orderIds, err := b.GetAcmeState().ListOrderIds(ac.sc, acct.KeyId)
 	if err != nil {
 		return nil, err
@@ -704,10 +766,28 @@ func (b *backend) acmeListOrdersHandler(ac *acmeContext, _ *logical.Request, _ *
 		},
 	}
 
+	var role string
+	var issuerName string
+	var issuerId string
+	if ac.Role != nil {
+		role = ac.Role.Name
+	}
+	if ac.Issuer != nil {
+		issuerName = ac.Issuer.Name
+		issuerId = ac.Issuer.ID.String()
+	}
+
+	b.pkiObserver.RecordPKIObservation(ac, req, observe.ObservationTypePKIAcmeListOrders,
+		observe.NewAdditionalPKIMetadata("role", role),
+		observe.NewAdditionalPKIMetadata("issuer_name", issuerName),
+		observe.NewAdditionalPKIMetadata("issuer_id", issuerId),
+		observe.NewAdditionalPKIMetadata("order_ids", orderIds),
+	)
+
 	return resp, nil
 }
 
-func (b *backend) acmeNewOrderHandler(ac *acmeContext, _ *logical.Request, _ *framework.FieldData, _ *jwsCtx, data map[string]interface{}, account *acmeAccount) (*logical.Response, error) {
+func (b *backend) acmeNewOrderHandler(ac *acmeContext, req *logical.Request, _ *framework.FieldData, _ *jwsCtx, data map[string]interface{}, account *acmeAccount) (*logical.Response, error) {
 	identifiers, err := parseOrderIdentifiers(data)
 	if err != nil {
 		return nil, err
@@ -784,6 +864,28 @@ func (b *backend) acmeNewOrderHandler(ac *acmeContext, _ *logical.Request, _ *fr
 	// > If the server is willing to issue the requested certificate, it
 	// > responds with a 201 (Created) response.
 	resp.Data[logical.HTTPStatusCode] = http.StatusCreated
+
+	var role string
+	var issuerName string
+	var issuerId string
+	if ac.Role != nil {
+		role = ac.Role.Name
+	}
+	if ac.Issuer != nil {
+		issuerName = ac.Issuer.Name
+		issuerId = ac.Issuer.ID.String()
+	}
+
+	b.pkiObserver.RecordPKIObservation(ac, req, observe.ObservationTypePKIAcmeNewOrder,
+		observe.NewAdditionalPKIMetadata("role", role),
+		observe.NewAdditionalPKIMetadata("issuer_name", issuerName),
+		observe.NewAdditionalPKIMetadata("issuer_id", issuerId),
+		observe.NewAdditionalPKIMetadata("not_before", notBefore),
+		observe.NewAdditionalPKIMetadata("not_after", notAfter),
+		observe.NewAdditionalPKIMetadata("order_id", order.OrderId),
+		observe.NewAdditionalPKIMetadata("account_id", order.AccountId),
+	)
+
 	return resp, nil
 }
 
