@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2016, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package pki
@@ -15,6 +15,7 @@ import (
 	"time"
 
 	"github.com/hashicorp/vault/builtin/logical/pki/issuing"
+	"github.com/hashicorp/vault/builtin/logical/pki/observe"
 	"github.com/hashicorp/vault/sdk/framework"
 	"github.com/hashicorp/vault/sdk/helper/certutil"
 	"github.com/hashicorp/vault/sdk/helper/consts"
@@ -469,6 +470,8 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 		}
 	}
 
+	b.pkiCertificateCounter.AddIssuedCertificate(!role.NoStore)
+
 	if useCSR {
 		if role.UseCSRCommonName && data.Get("common_name").(string) != "" {
 			resp.AddWarning("the common_name field was provided but the role is set with \"use_csr_common_name\" set to true")
@@ -480,6 +483,18 @@ func (b *backend) pathIssueSignCert(ctx context.Context, req *logical.Request, d
 
 	resp = addWarnings(resp, warnings)
 
+	b.pkiObserver.RecordPKIObservation(ctx, req, observe.ObservationTypePKIIssue,
+		observe.NewAdditionalPKIMetadata("issuer_name", role.Issuer),
+		observe.NewAdditionalPKIMetadata("signed", useCSR),
+		observe.NewAdditionalPKIMetadata("role_name", role.Name),
+		observe.NewAdditionalPKIMetadata("stored", !role.NoStore),
+		observe.NewAdditionalPKIMetadata("not_after", parsedBundle.Certificate.NotAfter.String()),
+		observe.NewAdditionalPKIMetadata("not_before", parsedBundle.Certificate.NotBefore.String()),
+		observe.NewAdditionalPKIMetadata("is_ca", parsedBundle.Certificate.IsCA),
+		observe.NewAdditionalPKIMetadata("serial_number", parsedBundle.Certificate.SerialNumber.String()),
+		observe.NewAdditionalPKIMetadata("lease_generated", generateLease),
+	)
+
 	return resp, nil
 }
 
