@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2016, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package pki
@@ -14,6 +14,7 @@ import (
 	"time"
 
 	"github.com/hashicorp/vault/builtin/logical/pki/issuing"
+	"github.com/hashicorp/vault/builtin/logical/pki/observe"
 	"github.com/hashicorp/vault/builtin/logical/pki/revocation"
 	"github.com/hashicorp/vault/sdk/framework"
 	"github.com/hashicorp/vault/sdk/helper/errutil"
@@ -505,6 +506,13 @@ func (b *backend) pathImportIssuers(ctx context.Context, req *logical.Request, d
 		}
 	}
 
+	b.pkiObserver.RecordPKIObservation(ctx, req, observe.ObservationTypePKIIssuersImport,
+		observe.NewAdditionalPKIMetadata("mapping", issuerKeyMap),
+		observe.NewAdditionalPKIMetadata("imported_keys", createdKeys),
+		observe.NewAdditionalPKIMetadata("imported_issuers", createdIssuers),
+		observe.NewAdditionalPKIMetadata("existing_keys", existingKeys),
+		observe.NewAdditionalPKIMetadata("existing_issuers", existingIssuers))
+
 	return response, nil
 }
 
