@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2016, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package pki
@@ -13,6 +13,7 @@ import (
 	"time"
 
 	"github.com/hashicorp/vault/builtin/logical/pki/issuing"
+	"github.com/hashicorp/vault/builtin/logical/pki/observe"
 	"github.com/hashicorp/vault/sdk/framework"
 	"github.com/hashicorp/vault/sdk/helper/certutil"
 	"github.com/hashicorp/vault/sdk/helper/consts"
@@ -373,7 +374,7 @@ non-Hostname, non-Email address CNs.`,
 			Type: framework.TypeCommaStringSlice,
 			Description: `A comma-separated string or list of policy OIDs, or a JSON list of qualified policy
 information, which must include an oid, and may include a notice and/or cps url, using the form 
-[{"oid"="1.3.6.1.4.1.7.8","notice"="I am a user Notice"}, {"oid"="1.3.6.1.4.1.44947.1.2.4 ","cps"="https://example.com"}].`,
+[{"oid"="1.3.6.1.4.1.7.8","notice"="I am a user Notice"}, {"oid"="1.3.6.1.4.1.32473.1.2.4","cps"="https://example.com"}].`,
 		},
 
 		"basic_constraints_valid_for_non_ca": {
@@ -801,7 +802,7 @@ non-Hostname, non-Email address CNs.`,
 				Type: framework.TypeCommaStringSlice,
 				Description: `A comma-separated string or list of policy OIDs, or a JSON list of qualified policy
 information, which must include an oid, and may include a notice and/or cps url, using the form 
-[{"oid"="1.3.6.1.4.1.7.8","notice"="I am a user Notice"}, {"oid"="1.3.6.1.4.1.44947.1.2.4 ","cps"="https://example.com"}].`,
+[{"oid"="1.3.6.1.4.1.7.8","notice"="I am a user Notice"}, {"oid"="1.3.6.1.4.1.32473.1.2.4","cps"="https://example.com"}].`,
 			},
 
 			"basic_constraints_valid_for_non_ca": {
@@ -920,11 +921,16 @@ func (b *backend) GetRole(ctx context.Context, s logical.Storage, n string) (*is
 }
 
 func (b *backend) pathRoleDelete(ctx context.Context, req *logical.Request, data *framework.FieldData) (*logical.Response, error) {
-	err := req.Storage.Delete(ctx, "role/"+data.Get("name").(string))
+	roleName := data.Get("name").(string)
+	err := req.Storage.Delete(ctx, "role/"+roleName)
 	if err != nil {
 		return nil, err
 	}
 
+	b.pkiObserver.RecordPKIObservation(ctx, req, observe.ObservationTypePKIRoleDelete,
+		observe.NewAdditionalPKIMetadata("role_name", roleName),
+	)
+
 	return nil, nil
 }
 
@@ -945,6 +951,12 @@ func (b *backend) pathRoleRead(ctx context.Context, req *logical.Request, data *
 	resp := &logical.Response{
 		Data: role.ToResponseData(),
 	}
+
+	b.pkiObserver.RecordPKIObservation(ctx, req, observe.ObservationTypePKIRoleRead,
+		observe.NewAdditionalPKIMetadata("issuer_name", role.Issuer),
+		observe.NewAdditionalPKIMetadata("role_name", role.Name),
+	)
+
 	return resp, nil
 }
 
@@ -1067,6 +1079,16 @@ func (b *backend) pathRoleCreate(ctx context.Context, req *logical.Request, data
 		return nil, err
 	}
 
+	b.pkiObserver.RecordPKIObservation(ctx, req, observe.ObservationTypePKIRoleWrite,
+		observe.NewAdditionalPKIMetadata("issuer_name", entry.Issuer),
+		observe.NewAdditionalPKIMetadata("role_name", entry.Name),
+		observe.NewAdditionalPKIMetadata("max_ttl", entry.MaxTTL.String()),
+		observe.NewAdditionalPKIMetadata("ttl", entry.TTL.String()),
+		observe.NewAdditionalPKIMetadata("no_store", entry.NoStore),
+		observe.NewAdditionalPKIMetadata("not_after", entry.NotAfter),
+		observe.NewAdditionalPKIMetadata("not_before", entry.NotBeforeDuration.String()),
+	)
+
 	return resp, nil
 }
 
@@ -1282,6 +1304,16 @@ func (b *backend) pathRolePatch(ctx context.Context, req *logical.Request, data
 		return nil, err
 	}
 
+	b.pkiObserver.RecordPKIObservation(ctx, req, observe.ObservationTypePKIRolePatch,
+		observe.NewAdditionalPKIMetadata("issuer_name", entry.Issuer),
+		observe.NewAdditionalPKIMetadata("role_name", entry.Name),
+		observe.NewAdditionalPKIMetadata("max_ttl", entry.MaxTTL.String()),
+		observe.NewAdditionalPKIMetadata("ttl", entry.TTL.String()),
+		observe.NewAdditionalPKIMetadata("no_store", entry.NoStore),
+		observe.NewAdditionalPKIMetadata("not_after", entry.NotAfter),
+		observe.NewAdditionalPKIMetadata("not_before", entry.NotBeforeDuration.String()),
+	)
+
 	return resp, nil
 }
 
